<?xml version="1.0" encoding="iso-8859-1"?>
<!-- $Id: record_preprint.xsl,v 1.1 2004/01/22 13:10:03 franck Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
<xsl:strip-space elements="*"/>

<xsl:variable name="lang" select="'::LANG'"/>
<xsl:variable name="labels" select="'::LABELS'"/>

<xsl:output method="html" indent="no" encoding="utf-8"/>

<xsl:template match="/">
    <style type="text/css">
        <xsl:comment>
            .label {
                font-family: helvetica;
                font-size: 12;
                font-weight: bold;
                vertical-align: top;
                width: 10%;
            }
            .data {
                font-family: helvetica;
                font-size: 12;
                vertical-align: top;
                width: 90%;
            }
        </xsl:comment>
    </style>

    <table>
        <xsl:apply-templates select="/record"/>
    </table>
    <xsl:value-of select="record/rights"/>
</xsl:template>

<xsl:template match="/record"
    xmlns:oai_dc="http://www.openarchives.org/OAI/2.0/oai_dc/"
    xmlns:dc="http://purl.org/dc/elements/1.1/"
    xmlns:bio="http://www.biomedcentral.com/oai/2.0/XML/schemas/">

    <xsl:apply-templates select="metadata/oai_dc:dc"/>
    <xsl:if test="metadata/oai_dc:dc/dc:rights or bio:rights">
        <tr>        
            <td class="label" valign="top">
                <xsl:call-template name="label">
                    <xsl:with-param name="label" select="'RIGHTS'"/>
                </xsl:call-template>
            </td>
            <td class="data">
                <xsl:for-each select="metadata/oai_dc:dc/dc:rights | bio:rights">
                    <xsl:value-of select="."/>
                    <xsl:if test="position ()!=last ()">
                        <br/>
                    </xsl:if>
                </xsl:for-each>
            </td>
        </tr>
    </xsl:if>
    <xsl:apply-templates select="server"/>
    <tr>        
        <td class="label" valign="top">
            <xsl:call-template name="label">
                <xsl:with-param name="label" select="'ADMIN'"/>
            </xsl:call-template>
        </td>
        <td class="data">
            <b>server: </b>
            <xsl:choose>
                <xsl:when test="server/infoName">
                    <xsl:value-of select="server/infoName"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="server/name"/>
                </xsl:otherwise>
            </xsl:choose>
            <b> date: </b>
            <xsl:value-of select="header/datestamp"/>
            <br/>
            <b>id: </b>
            <xsl:value-of select="header/identifier"/>
            <b> format: </b>
            <xsl:value-of select="server/format"/>
        </td>
    </tr>
</xsl:template>

<xsl:template match="/record/server">
    <xsl:call-template name="element">
        <xsl:with-param name="ele" select="setName"/>
        <xsl:with-param name="sep" select="'; '"/>
    </xsl:call-template>
</xsl:template>

<xsl:template match="/record/metadata/oai_dc:dc"
    xmlns:oai_dc="http://www.openarchives.org/OAI/2.0/oai_dc/"
    xmlns:dc="http://purl.org/dc/elements/1.1/">

    <xsl:call-template name="element">
        <xsl:with-param name="ele" select="dc:title"/>
        <xsl:with-param name="sep" select="'; '"/>
    </xsl:call-template>

    <xsl:apply-templates select="dc:identifier"/>

    <xsl:call-template name="element">
        <xsl:with-param name="ele" select="dc:language"/>
        <xsl:with-param name="sep" select="'; '"/>
    </xsl:call-template>
    <xsl:call-template name="element">
        <xsl:with-param name="ele" select="dc:creator"/>
        <xsl:with-param name="sep" select="'; '"/>
    </xsl:call-template>
    <xsl:call-template name="element">
        <xsl:with-param name="ele" select="dc:contributor"/>
        <xsl:with-param name="sep" select="'; '"/>
    </xsl:call-template>
    <xsl:call-template name="element">
        <xsl:with-param name="ele" select="dc:description"/>
        <xsl:with-param name="sep" select="'; '"/>
    </xsl:call-template>
    <xsl:call-template name="element">
        <xsl:with-param name="ele" select="dc:subject"/>
        <xsl:with-param name="sep" select="'; '"/>
    </xsl:call-template>
    <xsl:call-template name="element">
        <xsl:with-param name="ele" select="dc:publisher"/>
        <xsl:with-param name="sep" select="'; '"/>
    </xsl:call-template>
    <xsl:call-template name="element">
        <xsl:with-param name="ele" select="dc:coverage"/>
        <xsl:with-param name="sep" select="'; '"/>
    </xsl:call-template>
    <xsl:call-template name="element">
        <xsl:with-param name="ele" select="dc:source"/>
        <xsl:with-param name="sep" select="'; '"/>
    </xsl:call-template>
    <xsl:call-template name="element">
        <xsl:with-param name="ele" select="dc:date"/>
        <xsl:with-param name="sep" select="'; '"/>
    </xsl:call-template>
    <xsl:call-template name="element">
        <xsl:with-param name="ele" select="dc:type"/>
        <xsl:with-param name="sep" select="'; '"/>
    </xsl:call-template>
    <xsl:call-template name="element">
        <xsl:with-param name="ele" select="dc:format"/>
        <xsl:with-param name="sep" select="'; '"/>
    </xsl:call-template>
    <xsl:call-template name="element">
        <xsl:with-param name="ele" select="dc:relation"/>
        <xsl:with-param name="sep" select="'; '"/>
    </xsl:call-template>
</xsl:template>

<xsl:template match="/record/metadata/oai_dc:dc/dc:identifier"
    xmlns:oai_dc="http://www.openarchives.org/OAI/2.0/oai_dc/"
    xmlns:dc="http://purl.org/dc/elements/1.1/">

    <tr>        
    <xsl:choose>
        <xsl:when test="starts-with (., 'http:') or starts-with (., 'HTTP:') or starts-with (., 'ftp:') or starts-with (., 'FTP:')">
            <td class="label" valign="top">
                <xsl:call-template name="label">
                    <xsl:with-param name="label" select="'URL'"/>
                </xsl:call-template>
            </td>
            <td class="data">
                <xsl:element name="a">
                    <xsl:attribute name="href">
                        <xsl:value-of select="."/>
                    </xsl:attribute>
                    <xsl:value-of select="."/>
                </xsl:element>
            </td>
        </xsl:when>
        <xsl:otherwise>
            <td class="label" valign="top">
                <xsl:call-template name="label">
                    <xsl:with-param name="label" select="'dc:identifier'"/>
                </xsl:call-template>
            </td>
            <td class="data">
                <xsl:value-of select="."/>
            </td>
        </xsl:otherwise>
    </xsl:choose>
    </tr>
</xsl:template>

<xsl:template name="element">
    <xsl:param name="ele"/>
    <xsl:param name="sep"/>

    <xsl:if test="$ele">
        <tr>
            <td class="label" valign="top">
                <xsl:call-template name="label">
                    <xsl:with-param name="label" select="name ($ele)"/>
                </xsl:call-template>
            </td>
            <td class="data">
                <xsl:for-each select="$ele">
                    <xsl:apply-templates select="."/>
                    <xsl:if test="position ()!=last ()">
                        <xsl:value-of select="$sep"/>
                    </xsl:if>
                </xsl:for-each>
            </td>
        </tr>
    </xsl:if>
</xsl:template>

<xsl:template name="label">
    <xsl:param name="label"/>

    <xsl:variable name="lab">
        <xsl:if test="string-length ($labels) > 0">
            <xsl:value-of select="document($labels)/label/lab[@code=$label and @lang=$lang]/@text"/>
        </xsl:if>
    </xsl:variable>
    <xsl:choose>
        <xsl:when test="string-length ($lab) > 0">
            <xsl:value-of select="$lab"/>
        </xsl:when>
        <xsl:otherwise>
            <xsl:value-of select="concat ($label, '-', $lang)"/>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>

</xsl:stylesheet>
